@@ -1,4 +1,5 @@
-from cosmoglobe.h5.model import model_from_chain
+from cosmoglobe.sky import model_from_chain
+from cosmoglobe.sky.model import SkyModel
+from cosmoglobe.h5.chain import Chain
 from cosmoglobe.hub import get_test_chain
 from cosmoglobe.plot import plot, gnom, trace
-from cosmoglobe.h5.chain import Chain
